GraphicsBuilder

Struct GraphicsBuilder 

pub struct GraphicsBuilder<F>
where F: Fn(&mut Graphics),
{ /* private fields */ }
Builder for creating a Graphics instance.

Implementations

Source

impl<F> GraphicsBuilder<F>
where F: Fn(&mut Graphics),

pub fn new() -> GraphicsBuilder<F>

Create a new empty GraphicsBuilder By default there is no resource manager or resource initializer, dimensions are 0, 0, name is empty

Examples found in repository?
examples/hello.rs (line 61)
59async fn main() {
60    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
61    let graphics = graphics::GraphicsBuilder::new()
62        .window_name(String::from("game"))
63        .dimensions((500, 500))
64        .resource_manager(resource_manager.clone())
65        // we bulk load resources here because either we'll have to deal with
66        // ownership of `graphics` (the actual `let graphics`, not the closure
67        // argument)
68        // you may think of it like about just some initialization func
69        .initializer(|graphics| {
70            resource_manager.lock().unwrap().load_dir(PathBuf::from("assets"), graphics).unwrap();
71        })
72        .build();
73    let mut window = Window::new(graphics.unwrap(), resource_manager);
74
75    // because events::run takes a `&'static mut dyn WindowEventHandler` as a second argument we
76    // need to do this seemingly weird thing (while `app.rs` in fennel-engine has an ass solution
77    // with raw pointers lmfao) 
78    let handler: &'static mut dyn WindowEventHandler = {
79        let boxed = Box::new(State);
80        Box::leak(boxed) as &'static mut dyn WindowEventHandler
81    };
82    events::run(&mut window, handler).await;
83}
pub fn resource_manager( self, resource_manager: Arc<Mutex<ResourceManager>>, ) -> GraphicsBuilder<F>

Set the resource manager

Examples found in repository?
examples/hello.rs (line 64)
59async fn main() {
60    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
61    let graphics = graphics::GraphicsBuilder::new()
62        .window_name(String::from("game"))
63        .dimensions((500, 500))
64        .resource_manager(resource_manager.clone())
65        // we bulk load resources here because either we'll have to deal with
66        // ownership of `graphics` (the actual `let graphics`, not the closure
67        // argument)
68        // you may think of it like about just some initialization func
69        .initializer(|graphics| {
70            resource_manager.lock().unwrap().load_dir(PathBuf::from("assets"), graphics).unwrap();
71        })
72        .build();
73    let mut window = Window::new(graphics.unwrap(), resource_manager);
74
75    // because events::run takes a `&'static mut dyn WindowEventHandler` as a second argument we
76    // need to do this seemingly weird thing (while `app.rs` in fennel-engine has an ass solution
77    // with raw pointers lmfao) 
78    let handler: &'static mut dyn WindowEventHandler = {
79        let boxed = Box::new(State);
80        Box::leak(boxed) as &'static mut dyn WindowEventHandler
81    };
82    events::run(&mut window, handler).await;
83}
pub fn dimensions(self, dimensions: (u32, u32)) -> GraphicsBuilder<F>

Set the window dimensions

Examples found in repository?
examples/hello.rs (line 63)
59async fn main() {
60    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
61    let graphics = graphics::GraphicsBuilder::new()
62        .window_name(String::from("game"))
63        .dimensions((500, 500))
64        .resource_manager(resource_manager.clone())
65        // we bulk load resources here because either we'll have to deal with
66        // ownership of `graphics` (the actual `let graphics`, not the closure
67        // argument)
68        // you may think of it like about just some initialization func
69        .initializer(|graphics| {
70            resource_manager.lock().unwrap().load_dir(PathBuf::from("assets"), graphics).unwrap();
71        })
72        .build();
73    let mut window = Window::new(graphics.unwrap(), resource_manager);
74
75    // because events::run takes a `&'static mut dyn WindowEventHandler` as a second argument we
76    // need to do this seemingly weird thing (while `app.rs` in fennel-engine has an ass solution
77    // with raw pointers lmfao) 
78    let handler: &'static mut dyn WindowEventHandler = {
79        let boxed = Box::new(State);
80        Box::leak(boxed) as &'static mut dyn WindowEventHandler
81    };
82    events::run(&mut window, handler).await;
83}
pub fn window_name(self, name: String) -> GraphicsBuilder<F>

Set the window name

Examples found in repository?
examples/hello.rs (line 62)
59async fn main() {
60    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
61    let graphics = graphics::GraphicsBuilder::new()
62        .window_name(String::from("game"))
63        .dimensions((500, 500))
64        .resource_manager(resource_manager.clone())
65        // we bulk load resources here because either we'll have to deal with
66        // ownership of `graphics` (the actual `let graphics`, not the closure
67        // argument)
68        // you may think of it like about just some initialization func
69        .initializer(|graphics| {
70            resource_manager.lock().unwrap().load_dir(PathBuf::from("assets"), graphics).unwrap();
71        })
72        .build();
73    let mut window = Window::new(graphics.unwrap(), resource_manager);
74
75    // because events::run takes a `&'static mut dyn WindowEventHandler` as a second argument we
76    // need to do this seemingly weird thing (while `app.rs` in fennel-engine has an ass solution
77    // with raw pointers lmfao) 
78    let handler: &'static mut dyn WindowEventHandler = {
79        let boxed = Box::new(State);
80        Box::leak(boxed) as &'static mut dyn WindowEventHandler
81    };
82    events::run(&mut window, handler).await;
83}
pub fn initializer(self, initializer: F) -> GraphicsBuilder<F>
where F: Fn(&mut Graphics),

Set the resource initializer (closure)

Examples found in repository?
examples/hello.rs (lines 69-71)
59async fn main() {
60    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
61    let graphics = graphics::GraphicsBuilder::new()
62        .window_name(String::from("game"))
63        .dimensions((500, 500))
64        .resource_manager(resource_manager.clone())
65        // we bulk load resources here because either we'll have to deal with
66        // ownership of `graphics` (the actual `let graphics`, not the closure
67        // argument)
68        // you may think of it like about just some initialization func
69        .initializer(|graphics| {
70            resource_manager.lock().unwrap().load_dir(PathBuf::from("assets"), graphics).unwrap();
71        })
72        .build();
73    let mut window = Window::new(graphics.unwrap(), resource_manager);
74
75    // because events::run takes a `&'static mut dyn WindowEventHandler` as a second argument we
76    // need to do this seemingly weird thing (while `app.rs` in fennel-engine has an ass solution
77    // with raw pointers lmfao) 
78    let handler: &'static mut dyn WindowEventHandler = {
79        let boxed = Box::new(State);
80        Box::leak(boxed) as &'static mut dyn WindowEventHandler
81    };
82    events::run(&mut window, handler).await;
83}
pub fn resizable(self, resizable: bool) -> GraphicsBuilder<F>

Will the window be resizable?

pub fn fullscreen(self, fullscreen: bool) -> GraphicsBuilder<F>

Will the window be fullscreen?

pub fn centered(self, centered: bool) -> GraphicsBuilder<F>

Will the window be centered?

pub fn build(self) -> Result<Graphics>

Build Graphics

Panic

Panics if no resource manager or initializer was provided

Examples found in repository?
examples/hello.rs (line 72)
59async fn main() {
60    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
61    let graphics = graphics::GraphicsBuilder::new()
62        .window_name(String::from("game"))
63        .dimensions((500, 500))
64        .resource_manager(resource_manager.clone())
65        // we bulk load resources here because either we'll have to deal with
66        // ownership of `graphics` (the actual `let graphics`, not the closure
67        // argument)
68        // you may think of it like about just some initialization func
69        .initializer(|graphics| {
70            resource_manager.lock().unwrap().load_dir(PathBuf::from("assets"), graphics).unwrap();
71        })
72        .build();
73    let mut window = Window::new(graphics.unwrap(), resource_manager);
74
75    // because events::run takes a `&'static mut dyn WindowEventHandler` as a second argument we
76    // need to do this seemingly weird thing (while `app.rs` in fennel-engine has an ass solution
77    // with raw pointers lmfao) 
78    let handler: &'static mut dyn WindowEventHandler = {
79        let boxed = Box::new(State);
80        Box::leak(boxed) as &'static mut dyn WindowEventHandler
81    };
82    events::run(&mut window, handler).await;
83}