Graphics

Struct Graphics 

pub struct Graphics {
    pub canvas: Canvas<Window>,
    pub sdl_context: Sdl,
    pub texture_creator: Rc<TextureCreator<WindowContext>>,
    pub ttf_context: Sdl3TtfContext,
    /* private fields */
}
Owned SDL variables used for rendering

  • canvas: the drawing surface for the window
  • sdl_context: the SDL context

Fields

canvas: Canvas<Window>

The SDL3 canvas, required to draw

sdl_context: Sdl

SDL3 contaxt

texture_creator: Rc<TextureCreator<WindowContext>>

SDL3 texture creator

ttf_context: Sdl3TtfContext

SDL3 TTF context required for text rendering

Implementations

Source

impl Graphics

pub fn new( name: String, dimensions: (u32, u32), resource_manager: Arc<Mutex<ResourceManager>>, ) -> Result<Graphics, Box<dyn Error>>

Initialize SDL3, create a centered, resizable window and return a Graphics container with the canvas and SDL context.

Parameters
  • name: Window title.
  • dimensions: (width, height) in pixels (u32).
Returns
  • Ok(Graphics) on success.
  • Err(Box<dyn std::error::Error>) on failure (window/canvas build error).
Example
let graphics = graphics::new(String::from("my cool game"), (500, 500))?;
Examples found in repository?
examples/hello.rs (lines 63-67)
61async fn main() {
62    let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
63    let graphics = graphics::Graphics::new(
64        String::from("my cool window"),
65        (500, 500),
66        resource_manager.clone(),
67    );
68    let mut window = Window::new(graphics.unwrap(), resource_manager);
69    events::run(&mut window, State).await;
70}
pub fn draw_image(&mut self, path: String, position: (f32, f32)) -> Result<()>

Cache an image if it isn’t cached and draw it on the canvas

Parameters
  • path: Path to the image
  • position: Where to draw the image in the window (x,y) in pixels (f32).
Returns
  • Ok(()) on success.
  • Err(Box<dyn std::error::Error>) on failure
Example
graphics.draw_image(String::from("examples/example.png"), (0.0, 0.0)).await;
Examples found in repository?
examples/hello.rs (line 25)
20    fn draw(&self, window: &mut Window) -> anyhow::Result<()> {
21        window.graphics.canvas.set_draw_color(Color::RGB(0, 0, 0));
22        window.graphics.canvas.clear();
23        window
24            .graphics
25            .draw_image("assets/example.png".to_string(), (0.0, 0.0))
26            .expect("failed to draw an image");
27        window.graphics.draw_text(
28            String::from("hi"),
29            (64.0, 64.0),
30            String::from("assets/terminus.ttf"),
31            Color::RGBA(255, 0, 0, 0),
32            16.0,
33        )?;
34        window.graphics.draw_text(
35            String::from("hi"),
36            (64.0, 150.0),
37            String::from("assets/terminus.ttf"),
38            Color::RGBA(255, 0, 0, 0),
39            128.0,
40        )?;
41        window.graphics.canvas.present();
42        Ok(())
43    }
pub fn draw_text( &mut self, text: String, position: (f32, f32), font_path: String, color: Color, size: f32, ) -> Result<()>

Create a texture from font + text and render it on the canvas

Examples found in repository?
examples/hello.rs (lines 27-33)
20    fn draw(&self, window: &mut Window) -> anyhow::Result<()> {
21        window.graphics.canvas.set_draw_color(Color::RGB(0, 0, 0));
22        window.graphics.canvas.clear();
23        window
24            .graphics
25            .draw_image("assets/example.png".to_string(), (0.0, 0.0))
26            .expect("failed to draw an image");
27        window.graphics.draw_text(
28            String::from("hi"),
29            (64.0, 64.0),
30            String::from("assets/terminus.ttf"),
31            Color::RGBA(255, 0, 0, 0),
32            16.0,
33        )?;
34        window.graphics.draw_text(
35            String::from("hi"),
36            (64.0, 150.0),
37            String::from("assets/terminus.ttf"),
38            Color::RGBA(255, 0, 0, 0),
39            128.0,
40        )?;
41        window.graphics.canvas.present();
42        Ok(())
43    }